@@ -26,27 +26,31 @@ class JoseError(Exception):
 # --- Key related errors --- #
 
 
+class KeyParameterError(JoseError):
+    error = "key_parameter"
+
+
 class MissingKeyError(JoseError):
     error = "missing_key"
 
 
-class UnsupportedKeyUseError(JoseError):
+class UnsupportedKeyUseError(KeyParameterError):
     error = "unsupported_key_use"
 
 
-class UnsupportedKeyAlgorithmError(JoseError):
+class UnsupportedKeyAlgorithmError(KeyParameterError):
     error = "unsupported_key_alg"
 
 
-class UnsupportedKeyOperationError(JoseError):
+class UnsupportedKeyOperationError(KeyParameterError):
     error = "unsupported_key_operation"
 
 
-class MissingKeyTypeError(JoseError):
+class MissingKeyTypeError(KeyParameterError):
     error = "missing_key_type"
 
 
-class InvalidKeyTypeError(JoseError):
+class InvalidKeyTypeError(KeyParameterError):
     error = "invalid_key_type"
 
 
@@ -197,9 +201,10 @@ class ClaimError(JoseError):
     claim: str
     description = "Error claim: '{}'"
 
-    def __init__(self, claim: str):
+    def __init__(self, claim: str, description: str | None = None):
         self.claim = claim
-        description = self.description.format(claim)
+        if description is None:
+            description = self.description.format(claim)
         super(ClaimError, self).__init__(description=description)
 
 
@@ -227,22 +232,19 @@ class InsecureClaimError(ClaimError):
     description = "Insecure claim: '{}'"
 
 
-class ExpiredTokenError(JoseError):
+class ExpiredTokenError(ClaimError):
     """This error is designed for JWT. It raised when the token is expired."""
 
     error = "expired_token"
     description = "The token is expired"
 
 
-class InvalidTokenError(JoseError):
-    """This error is designed for JWT. It raised when the token is not valid yet."""
-
-    error = "invalid_token"
-    description = "The token is not valid yet"
-
-
 class InvalidPayloadError(JoseError):
     """This error is designed for JWT. It raised when the payload is
     not a valid JSON object."""
 
     error = "invalid_payload"
+
+
+# compatibility
+InvalidTokenError = InvalidClaimError
